function [ PSI_c ] = getCharacteristic( massflow, rspeed)
%getCharacteristic Returns the value of the compressor characteristic
%
%   Returns the value of the compressor characteristic
%   for different massflows and rotational speeds
%   based on a polyfit identification procedure

persistent c;
if isempty(c)
    'c read'
    c = dlmread('c_matrix');
end

c_currentspeed = [];
for i = 1 : 4
    c_currentspeed = [c_currentspeed; c(i,1)*rspeed^3 + c(i,2)*rspeed^2 + c(i,3)*rspeed + c(i,4)];
end

PSI_c = c_currentspeed(1)*massflow^3 + c_currentspeed(2)*massflow^2 + c_currentspeed(3)*massflow + c_currentspeed(4);


% MAKE THE CURVES MORE FLAT FOR LOW SPEEDS UNDER 20 000 RPM
if rspeed < 20000
    if massflow < 0
            PSI_c = 0.000003*massflow^2 + 1 + rspeed/20000*0.20;
    else
            PSI_c = -0.00003*massflow^2 + 1 + rspeed/20000*0.20;
    end
end


% ASSUMED MIN P02/P01 = 1
if PSI_c < 1
    PSI_c = 1;
end