% DEFINES THE SURGE AVOIDANCE LINE
%
% Author: Bjrn Ove Barstad

%surge margin
surge_margin = .3;

%define the speedlines
speedvector = 20000 : 5000 : 50000;

%obtain the bivariate cubic spline
%which contains all the data for
%the compressor characteristic
pp = load('psic_data');

%generate the speedlines
y = [];
w = -10 : 80;
for i = 1 : length(speedvector)
	y(i,:) = fnval(pp, {w, speedvector(i)});
end

%directional derivative of the bivariate
%cubic spline in the mass flow direction
dp = fndir(pp, [1; 0]);

%find maximum algorithm
MAX = zeros(2, length(speedvector));
for i = 1 : length(speedvector)
    max = -inf;
    for j = 1 : length(w)
        deriv = fnval(dp, {w(j), speedvector(i)});
        if abs(deriv) < 1e-4 %derivative ~ zero
            if max == -inf
                max = [w(j); fnval(pp, {w(j), speedvector(i)})];
            else
                try_max = [w(j); fnval(pp, {w(j), speedvector(i)})];
                if try_max(2) > max(2)
                    max = try_max;
                end
            end
        end
    end
    MAX(:,i) = max;
end

%makes the surge line defined by MAX linear
PF_surge = polyfit(MAX(1,:), MAX(2,:), 1);
save('sl','PF_surge');
y_surgeline = PF_surge(1).*w + PF_surge(2);

%along with the surge avoidance line
PF_avoid = polyfit(MAX(1,:).*(1 + surge_margin), MAX(2,:), 1);
save('scl','PF_avoid');
y_avoid = PF_avoid(1).*w + PF_avoid(2);

%draw
scrsz = get(0,'ScreenSize');
figure(2)
set(2,'Position',[(scrsz(3)/2 - 466/2) (scrsz(4)/2 - 411/2) 466 411]);
plot(w, y_surgeline, w, y_avoid, MAX(1,:), MAX(2,:), w, y(1,:), w, y(2,:), w, y(3,:), w, y(4,:), w, y(5,:), w, y(6,:), w, y(7,:)),grid,axis([-10 90 1.0 2.4])
xlabel('Corrected mass flow lb/min')
ylabel('Pressure ratio')
